@@ -27,15 +27,18 @@ except: #Py2
     import urllib
 
 try:
-    from socketserver import ForkingMixIn # Forking Not Supported Py3
+    from socketserver import ForkingMixIn # Forking Supported Py3
+    forking = True
 except:
     try:
-        from SocketServer import ForkingMixIn # Forking Not Supported Py2
+        from SocketServer import ForkingMixIn # Forking Supported Py2
+        forking = True
     except:
-        class ForkingMixIn(object):pass # Forking Not Supported
+        class ForkingMixIn(ThreadingMixIn):pass # Forking Not Supported
+        forking = False
 
 __version__ = "3.0.1"
-__all__ = ['WSGIServer', 'ThreadingWSGIServer', 'WSGIRequestHandler', 'demo_app', 'make_server']
+__all__ = ['WSGIServer', 'ThreadingWSGIServer', 'ForkingWSGIServer', 'WSGIRequestHandler', 'demo_app', 'make_server']
 
 
 server_version = "ServeLight/" + __version__
@@ -168,7 +171,7 @@ class ThreadingWSGIServer(ThreadingMixIn, WSGIServer):
     """
 
 
-class ForkingWSGIServer(ForkingMixIn, BaseWSGIServer):
+class ForkingWSGIServer(ForkingMixIn, WSGIServer):
 
     """A WSGI server that does forking.
     This class is identical to WSGIServer but handle each request in a new process 
